==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/ContactCenterActivity.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class ContactCenterActivity(nextActivity: Option[__string] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.ContactCenterActivity = {
    import ContactCenterActivity.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.ContactCenterActivity
      .builder()
      .optionallyWith(
        nextActivity.map(value => __string.unwrap(value): java.lang.String)
      )(_.nextActivity)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.ContactCenterActivity.ReadOnly =
    zio.aws.pinpoint.model.ContactCenterActivity.wrap(buildAwsValue())
}
object ContactCenterActivity {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.ContactCenterActivity
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.ContactCenterActivity =
      zio.aws.pinpoint.model
        .ContactCenterActivity(nextActivity.map(value => value))
    def nextActivity: Option[__string]
    def getNextActivity: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("nextActivity", nextActivity)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.ContactCenterActivity
  ) extends zio.aws.pinpoint.model.ContactCenterActivity.ReadOnly {
    override val nextActivity: Option[__string] = scala
      .Option(impl.nextActivity())
      .map(value => zio.aws.pinpoint.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.ContactCenterActivity
  ): zio.aws.pinpoint.model.ContactCenterActivity.ReadOnly = new Wrapper(impl)
}

==> zio-aws-pinpoint_3-5.17.267.1-sources.jar: zio/aws/pinpoint/model/ContactCenterActivity.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.pinpoint.model.primitives.__string
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ContactCenterActivity(
    nextActivity: Optional[__string] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.ContactCenterActivity = {
    import ContactCenterActivity.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.ContactCenterActivity
      .builder()
      .optionallyWith(nextActivity.map(value => value: java.lang.String))(
        _.nextActivity
      )
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.ContactCenterActivity.ReadOnly =
    zio.aws.pinpoint.model.ContactCenterActivity.wrap(buildAwsValue())
}
object ContactCenterActivity {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.ContactCenterActivity
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.ContactCenterActivity =
      zio.aws.pinpoint.model
        .ContactCenterActivity(nextActivity.map(value => value))
    def nextActivity: Optional[__string]
    def getNextActivity: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("nextActivity", nextActivity)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.ContactCenterActivity
  ) extends zio.aws.pinpoint.model.ContactCenterActivity.ReadOnly {
    override val nextActivity: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.nextActivity())
      .map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.ContactCenterActivity
  ): zio.aws.pinpoint.model.ContactCenterActivity.ReadOnly = new Wrapper(impl)
}
